@@ -1355,7 +1355,7 @@ static void *thread_main(void *data)
 		}
 	}
 
-	if (nice(td->nice) < 0) {
+	if (nice(td->nice) == -1) {
 		td_verror(td, errno);
 		goto err;
 	}
@@ -1679,7 +1679,7 @@ static void print_thread_status(void)
 	printf("Threads running: %d", nr_running);
 	if (m_rate || t_rate)
 		printf(", commitrate %d/%dKiB/sec", t_rate, m_rate);
-	if (eta_sec != INT_MAX) {
+	if (eta_sec != INT_MAX && nr_running) {
 		perc *= 100.0;
 		printf(": [%s] [%3.2f%% done] [eta %s]", run_str, perc,eta_str);
 	}
