@@ -5,6 +5,8 @@
 #include "os-linux.h"
 #elif defined(__FreeBSD__)
 #include "os-freebsd.h"
+#elif defined(__sun__)
+#include "os-solaris.h"
 #else
 #error "unsupported os"
 #endif
@@ -39,6 +41,12 @@
 #define ioprio_set(which, who, prio)	(0)
 #endif
 
+#ifndef FIO_HAVE_ODIRECT
+#define OS_O_DIRECT			0
+#else
+#define OS_O_DIRECT			O_DIRECT
+#endif
+
 struct thread_data;
 extern int fio_libaio_init(struct thread_data *);
 extern int fio_posixaio_init(struct thread_data *);
